@@ -5,14 +5,16 @@ Python supplemental features
 ----------------------------
 
 python_plus adds various features to python 2 and python 3 programs.
-It is designed to be used as integration of pypi future to help to port your code from Python 2 to Python 3 and still have it run on Python 2.
+It is designed to be used as integration of pypi future to help to port your code
+from Python 2 to Python 3 and still have it run on Python 2.
 
 
 vem: virtual environment manager
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This package is released with an nice command:
-**vem** that is an interactive tool with some nice features to manage standard virtual environment and it is osx/darwin compatible.
+**vem** that is an interactive tool with some nice features to manage
+standard virtual environment and it is osx/darwin compatible.
 """
 import os
 import sys
@@ -21,7 +23,7 @@ import gzip
 import shutil
 
 
-__version__ = '1.0.6'
+__version__ = '1.0.9'
 
 
 def fake_setup(**kwargs):
@@ -156,4 +158,4 @@ def main(cli_args=None):
             print(text)
     elif action in ('-C', '--copy-pkg-data'):
         copy_pkg_data(setup_args, verbose)
-    return 0
\ No newline at end of file
+    return 0
